#
# spec file for package libstoragemgmt
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname %{name}1
%bcond_with test

%if 0%{?suse_version} >= 1500 || %{with python3}
%define python3 1
%define python_sitelib %{python3_sitelib}
%else
%define python3 0
%endif

Name:           libstoragemgmt
Version:        1.6.0
Release:        lp150.1.5
Summary:        Storage array management library
License:        LGPL-2.1+ and GPL-2.0+
Group:          System/Libraries
Url:            https://github.com/libstorage/libstoragemgmt
Source0:        https://github.com/libstorage/libstoragemgmt/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libconfig-devel
BuildRequires:  pkgconfig
%if 0%{python3}
BuildRequires:  python3-devel
BuildRequires:  python3-pyudev
BuildRequires:  python3-pywbem
BuildRequires:  python3-six
Requires:       python3-six
%else
BuildRequires:  python-devel
BuildRequires:  python-pyudev
BuildRequires:  python-pywbem
BuildRequires:  python-six
Requires:       python-six
%endif
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
%if 0%{python3}
Requires:       python3-%{name}
Requires:       python3-%{name}-clibs
%else
Requires:       python2-%{name}
Requires:       python2-%{name}-clibs
%endif
%systemd_requires
%if %{with test}
BuildRequires:  chrpath
BuildRequires:  libtool
BuildRequires:  perl
BuildRequires:  procps
BuildRequires:  valgrind
BuildRequires:  pkgconfig(check)
%endif
%if 0%{?suse_version} <= 1320
# For SLE12 and openSUSE 13.2
BuildRequires:  libyajl-devel
%else
BuildRequires:  pkgconfig(yajl)
%endif

%description
The libStorageMgmt library will provide a vendor agnostic open source storage
application programming interface (API) that will allow management of storage
arrays.  The library includes a command line interface for interactive use and
scripting (command lsmcli).  The library also has a daemon that is used for
executing plug-ins in a separate process (lsmd).

%package        -n %{libname}
Summary:        Storage array management library
Group:          System/Libraries

%description    -n %{libname}
The libStorageMgmt library will provide a vendor agnostic open source storage
application programming interface (API) that will allow management of storage
arrays.  The library includes a command line interface for interactive use and
scripting (command lsmcli).  The library also has a daemon that is used for
executing plug-ins in a separate process (lsmd).

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if 0%{python3}
%package        -n python3-%{name}
%else
%package        -n python2-%{name}
%endif
Summary:        Python client libraries and plug-in support for %{name}
Group:          System/Libraries
Requires:       %{name} = %{version}
%if 0%{python3}
Requires:       python3-%{name}-clibs
%else
Requires:       python2-%{name}-clibs
%endif
BuildArch:      noarch

%if 0%{python3}
%description        -n python3-%{name}
%else
%description        -n python2-%{name}
%endif
The python-%{name} package contains python client libraries as
well as python framework support and open source plug-ins written in python.

%if 0%{python3}
%package        -n python3-%{name}-clibs
%else
%package        -n python2-%{name}-clibs
%endif
Summary:        Python C extension for %{name}
Group:          System/Libraries
Requires:       %{name} = %{version}

%if 0%{python3}
%description    -n python3-%{name}-clibs
%else
%description    -n python2-%{name}-clibs
%endif
The python-%{name}-clibs package contains python C extentions for %{name}.

%package        smis-plugin
Summary:        Files for SMI-S generic array support for %{name}
Group:          System/Libraries
%if 0%{python3}
Requires:       python3-pywbem
%else
Requires:       python-pywbem
%endif
Requires(post): %{name} = %{version}
Requires(postun): %{name} = %{version}
BuildArch:      noarch

%description    smis-plugin
The %{name}-smis-plugin package contains plug-in for generic SMI-S
array support.

%package        netapp-plugin
Summary:        Files for NetApp array support for %{name}
Group:          System/Libraries
Requires(post): %{name} = %{version}
Requires(postun): %{name} = %{version}
BuildArch:      noarch

%description    netapp-plugin
The %{name}-netapp-plugin package contains plug-in for NetApp array
support.

%package        targetd-plugin
Summary:        Files for targetd array support for %{name}
Group:          System/Libraries
Requires(post): %{name} = %{version}
Requires(postun): %{name} = %{version}
BuildArch:      noarch

%description    targetd-plugin
The %{name}-targetd-plugin package contains plug-in for targetd
array support.

%package        nstor-plugin
Summary:        Files for NexentaStor array support for %{name}
Group:          System/Libraries
Requires(post): %{name} = %{version}
Requires(postun): %{name} = %{version}
BuildArch:      noarch

%description    nstor-plugin
The %{name}-nstor-plugin package contains plug-in for NexentaStor
array support.

%package        udev
Summary:        Udev files for %{name}
Group:          System/Base

%description    udev
The %{name}-udev package contains udev rules and helper utilities for
uevents generated by the kernel.

%package        megaraid-plugin
Summary:        Files for LSI MegaRAID support for %{name}
Group:          System/Libraries
Requires(post): %{name} = %{version}
Requires(postun): %{name} = %{version}
BuildArch:      noarch

%description    megaraid-plugin
The %{name}-megaraid-plugin package contains the plugin for LSI MegaRAID
storage management via storcli.

%package        hpsa-plugin
Summary:        Files for HP SmartArray support for %{name}
Group:          System/Libraries
Requires(post): %{name} = %{version}
Requires(postun): %{name} = %{version}
BuildArch:      noarch

%description    hpsa-plugin
The %{name}-hpsa-plugin package contains the plugin for HP SmartArray storage
management via hpssacli.

%package        nfs-plugin
Summary:        Files for nfs support for %{name}
Group:          System/Libraries
Requires(post): %{name} = %{version}
Requires(postun): %{name} = %{version}
BuildArch:      noarch

%description    nfs-plugin
The %{name}-nfs-plugin package contains the plugin for nfs based storage.

%package        local-plugin
Summary:        Files for HP local pseudo support for %{name}
Group:          System/Libraries
Requires(post): %{name} = %{version}
Requires(postun): %{name} = %{version}
BuildArch:      noarch

%description    local-plugin
The %{name}-local-plugin package contains the plugin for local pseudo
storage.

%package        arcconf-plugin
Summary:        Files for Microsemi storage support for %{name}
Group:          System/Libraries
Requires(post): %{name} = %{version}
Requires(postun): %{name} = %{version}
BuildArch:      noarch

%description    arcconf-plugin
The %{name}-arcconf-plugin package contains the plugin for Microsemi
storage.

%prep
%setup -q

%build
%configure \
  --disable-static \
%if 0%{python3}
  --with-python3 \
%endif
%if ! %{with test}
  --without-test
%endif
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

install -d -m755 %{buildroot}/%{_sbindir}

install -Dpm 0644 packaging/daemon/libstoragemgmt.service \
    %{buildroot}/%{_unitdir}/libstoragemgmt.service
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

#tempfiles.d configuration for /var/run
mkdir -p %{buildroot}/%{_tmpfilesdir}
install -m 0644 packaging/daemon/lsm-tmpfiles.conf \
    %{buildroot}/%{_tmpfilesdir}/%{name}.conf

#Files for udev handling
install -d %{buildroot}/%{_udevrulesdir}
install -m 644 tools/udev/90-scsi-ua.rules \
    %{buildroot}/%{_udevrulesdir}/90-scsi-ua.rules
install -m 755 tools/udev/scan-scsi-target \
    %{buildroot}/%{_libexecdir}/udev/scan-scsi-target

# find all duplicates
%fdupes -s %{buildroot}%{python_sitelib}

%if %{with test}
%check
if ! make check
then
    cat test-suite.log || true
    exit 1
fi
%endif

%pre
if [ $1 -eq 1 ]; then
    # New install
    getent group %{name} >/dev/null || groupadd -r %{name}
    getent passwd %{name} >/dev/null || \
        useradd -r -g %{name} -d %{_localstatedir}/run/lsm -s /sbin/nologin \
        -c "daemon account for libstoragemgmt" %{name}
fi

%service_add_pre %{name}.service

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%post
%service_add_post %{name}.service
# Create tmp socket file on package new install.
if [ $1 -eq 1 -a -x %{_bindir}/systemd-tmpfiles ]; then
%if 0%{?suse_version} <= 1320
    systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf || :
%else
    %tmpfiles_create %{_tmpfilesdir}/%{name}.conf
%endif
fi

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%post smis-plugin
if [ $1 -eq 1 ]; then
    # New install.
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%postun smis-plugin
if [ $1 -eq 0 ]; then
    # Remove
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%post netapp-plugin
if [ $1 -eq 1 ]; then
    # New install.
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%postun netapp-plugin
if [ $1 -eq 0 ]; then
    # Remove
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%post targetd-plugin
if [ $1 -eq 1 ]; then
    # New install.
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%postun targetd-plugin
if [ $1 -eq 0 ]; then
    # Remove
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%post nstor-plugin
if [ $1 -eq 1 ]; then
    # New install.
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%postun nstor-plugin
if [ $1 -eq 0 ]; then
    # Remove
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%post megaraid-plugin
if [ $1 -eq 1 ]; then
    # New install.
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%postun megaraid-plugin
if [ $1 -eq 0 ]; then
    # Remove
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%post hpsa-plugin
if [ $1 -eq 1 ]; then
    # New install.
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%postun hpsa-plugin
if [ $1 -eq 0 ]; then
    # Remove
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%post nfs-plugin
if [ $1 -eq 1 ]; then
    # New install.
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%postun nfs-plugin
if [ $1 -eq 0 ]; then
    # Remove
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%post local-plugin
if [ $1 -eq 1 ]; then
    # New install.
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%postun local-plugin
if [ $1 -eq 0 ]; then
    # Remove
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%post arcconf-plugin
if [ $1 -eq 1 ]; then
    # New install.
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%postun arcconf-plugin
if [ $1 -eq 0 ]; then
    # Remove
    %{_bindir}/systemctl try-restart ${name}.service || :
fi

%post udev
%udev_rules_update

%files
%{_mandir}/man1/lsmcli.1%{ext_man}
%{_mandir}/man1/lsmd.1%{ext_man}
%{_mandir}/man5/lsmd.conf.5*
%{_bindir}/lsmcli
%{_bindir}/lsmd
%{_bindir}/simc_lsmplugin
%{_mandir}/man1/simc_lsmplugin.1%{ext_man}
%{_unitdir}/libstoragemgmt.service
%{_tmpfilesdir}/%{name}.conf
%dir %{_sysconfdir}/lsm
%config %{_sysconfdir}/bash_completion.d/lsmcli
%config(noreplace) %{_sysconfdir}/lsm/lsmd.conf
%dir %{_sysconfdir}/lsm/pluginconf.d
%{_sbindir}/rclibstoragemgmt
%ghost %dir /run/lsm
%ghost %dir /run/lsm/ipc

%files udev
%{_libexecdir}/udev/scan-scsi-target
%{_udevrulesdir}/90-scsi-ua.rules

%files -n %{libname}
%doc README COPYING.LIB
%{_libdir}/libstoragemgmt.so.*

%files devel
%{_includedir}/*
%{_mandir}/man3/*%{ext_man}
%{_libdir}/libstoragemgmt.so
%{_libdir}/pkgconfig/libstoragemgmt.pc

%if 0%{python3}
%files -n python3-%{name}
%else
%files -n python2-%{name}
%endif
%dir %{python_sitelib}/lsm
%{python_sitelib}/lsm/external
%{python_sitelib}/lsm/_*.py*
%{python_sitelib}/lsm/version.*
%if 0%{python3}
%dir %{python_sitelib}/lsm/__pycache__
%{python_sitelib}/lsm/__pycache__/*
%dir %{python_sitelib}/lsm/plugin/__pycache__
%{python_sitelib}/lsm/plugin/__pycache__/*
%dir %{python_sitelib}/lsm/plugin/sim/__pycache__
%{python_sitelib}/lsm/plugin/sim/__pycache__/*
%dir %{python_sitelib}/lsm/lsmcli/__pycache__
%{python_sitelib}/lsm/lsmcli/__pycache__/*
%endif
%dir %{python_sitelib}/lsm/plugin
%{python_sitelib}/lsm/plugin/__init__.*
%dir %{python_sitelib}/lsm/plugin/sim
%{python_sitelib}/lsm/plugin/sim/*.py*
%{python_sitelib}/lsm/lsmcli
%{_bindir}/sim_lsmplugin
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/sim.conf
%{_mandir}/man1/sim_lsmplugin.1%{ext_man}

%files smis-plugin
%dir %{python_sitelib}/lsm/plugin/smispy
%{python_sitelib}/lsm/plugin/smispy/*.py*
%if 0%{python3}
%dir %{python_sitelib}/lsm/plugin/smispy/__pycache__
%{python_sitelib}/lsm/plugin/smispy/__pycache__/*
%endif
%{_bindir}/smispy_lsmplugin
%{_mandir}/man1/smispy_lsmplugin.1%{ext_man}

%files netapp-plugin
%dir %{python_sitelib}/lsm/plugin/ontap
%{python_sitelib}/lsm/plugin/ontap/*.py*
%if 0%{python3}
%dir %{python_sitelib}/lsm/plugin/ontap/__pycache__
%{python_sitelib}/lsm/plugin/ontap/__pycache__/*
%endif
%{_bindir}/ontap_lsmplugin
%{_mandir}/man1/ontap_lsmplugin.1%{ext_man}

%files targetd-plugin
%dir %{python_sitelib}/lsm/plugin/targetd
%if 0%{python3}
%dir %{python_sitelib}/lsm/plugin/targetd/__pycache__
%{python_sitelib}/lsm/plugin/targetd/__pycache__/*
%endif
%{python_sitelib}/lsm/plugin/targetd/*.py*
%{_bindir}/targetd_lsmplugin
%{_mandir}/man1/targetd_lsmplugin.1%{ext_man}

%files nstor-plugin
%dir %{python_sitelib}/lsm/plugin/nstor
%if 0%{python3}
%dir %{python_sitelib}/lsm/plugin/nstor/__pycache__
%{python_sitelib}/lsm/plugin/nstor/__pycache__/*
%endif
%{python_sitelib}/lsm/plugin/nstor/*.py*
%{_bindir}/nstor_lsmplugin
%{_mandir}/man1/nstor_lsmplugin.1%{ext_man}

%files megaraid-plugin
%dir %{python_sitelib}/lsm/plugin/megaraid
%if 0%{python3}
%dir %{python_sitelib}/lsm/plugin/megaraid/__pycache__
%{python_sitelib}/lsm/plugin/megaraid/__pycache__/*
%endif
%{python_sitelib}/lsm/plugin/megaraid/*.py*
%{_bindir}/megaraid_lsmplugin
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/megaraid.conf
%{_mandir}/man1/megaraid_lsmplugin.1%{ext_man}

%files hpsa-plugin
%dir %{python_sitelib}/lsm/plugin/hpsa
%if 0%{python3}
%dir %{python_sitelib}/lsm/plugin/hpsa/__pycache__
%{python_sitelib}/lsm/plugin/hpsa/__pycache__/*
%endif
%{python_sitelib}/lsm/plugin/hpsa/*.py*
%{_bindir}/hpsa_lsmplugin
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/hpsa.conf
%{_mandir}/man1/hpsa_lsmplugin.1%{ext_man}

%files nfs-plugin
%dir %{python_sitelib}/lsm/plugin/nfs
%if 0%{python3}
%dir %{python_sitelib}/lsm/plugin/nfs/__pycache__
%{python_sitelib}/lsm/plugin/nfs/__pycache__/*
%endif
%{python_sitelib}/lsm/plugin/nfs/*.py*
%{_bindir}/nfs_lsmplugin
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/nfs.conf
%{_mandir}/man1/nfs_lsmplugin.1%{ext_man}

%files local-plugin
%dir %{python_sitelib}/lsm/plugin/local
%if 0%{python3}
%dir %{python_sitelib}/lsm/plugin/local/__pycache__
%{python_sitelib}/lsm/plugin/local/__pycache__/*
%endif
%{python_sitelib}/lsm/plugin/local/*.py*
%{_bindir}/local_lsmplugin
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/local.conf
%{_mandir}/man1/local_lsmplugin.1%{ext_man}

%files arcconf-plugin
%dir %{python_sitelib}/lsm/plugin/arcconf
%if 0%{python3}
%dir %{python_sitelib}/lsm/plugin/arcconf/__pycache__
%{python_sitelib}/lsm/plugin/arcconf/__pycache__/*
%endif
%{python_sitelib}/lsm/plugin/arcconf/*.py*
%{_bindir}/arcconf_lsmplugin
%config(noreplace) %{_sysconfdir}/lsm/pluginconf.d/arcconf.conf
%{_mandir}/man1/arcconf_lsmplugin.1%{ext_man}

%if 0%{python3}
%files -n python3-%{name}-clibs
%else
%files -n python2-%{name}-clibs
%endif
%{python_sitelib}/lsm/_clib.*
%{python_sitelib}/lsm/plugin/nfs/nfs_clib.*

%changelog
* Tue Dec 19 2017 nwang@suse.com
- bsc#1073088, change requirements to python3 for SLE15.
* Thu Oct 26 2017 mpluskal@suse.com
- Update to version 1.6.0:
  * New error number for deleting volume/fs with child dependency:
    + C: LSM_ERR_HAS_CHILD_DEPENDENCY
    + Python: lsm.ErrorNumber.HAS_CHILD_DEPENDENCY
  * Fix incorrect SCSI VPD query for 0x89 and 0xb1.
  * Fix regression on using libstoragemgmt with pywbem 0.7.0.
  * Updates on manpage and help message of lsmcli.
- Changes for version 1.5.0:
  * New plugin -- LibstorageMgmt NFS server plugin(nfs://).
  * New plugin -- LibstorageMgmt Local Pseudo plugin(local://).
  * New plugin -- LibstorageMgmt Microsemi storage plugin(arcconf://).
  * Removed support of lmiwbem due to missing self-signed CA verification and inactive upstream of lmiwbem.
  * Support SES actions on kernel bsg module(old code was using sg kernel module).
  * Add manpages for every C API using kernel-doc.
  * New URI parameter ca_cert_file for ONTAP, SMI-S, targetd plugin.
  * Bug fixes:
    + Fix the ONTAP SSL connection.
    + Sim plugin: Fix sqlite3 transaction of fs_child_dependency_rm().
    + MegaRAID: Handle when both perccli and storcli are installed.
    + MegaRAID plugin: Support pool status for rebuild and check.
    + Fixed C++ code compile warnings.
  * Library adds:
    + Query health status of local disk:
    + lsm_local_disk_health_status_get()/lsm.LocalDisk.health_status_get()
- Drop no longer needed patches:
  * 0001-Fix-gcc-warning-on-non-x86-platform.patch
  * 0001-Simc-plugin-Fix-gcc-warning-on-fallthrough-switch.patch
  * 0002-C-library-Bug-fix-for-incorrect-use-of-sizeof.patch
* Thu Jun  1 2017 nwang@suse.com
- To unify the package in SLE and Leap.
- bsc#931426, bsc#980651 and bsc#988547 also fixed in this package
* Thu May 18 2017 mliska@suse.cz
- Add 0001-Simc-plugin-Fix-gcc-warning-on-fallthrough-switch.patch to
  fix build with GCC 7.
* Tue May 16 2017 mpluskal@suse.com
- Sync patches with fedora:
  * 0002-C-library-Bug-fix-for-incorrect-use-of-sizeof.patch
* Tue Apr 25 2017 alarrosa@suse.com
- Add 0001-Fix-gcc-warning-on-non-x86-platform.patch to fix build in
  ppc64le/s390x.
* Mon Apr 24 2017 alarrosa@suse.com
- Remove dependency for python-M2Crypto which is no longer needed
- Add python-six dependency
* Fri Mar 24 2017 mpluskal@suse.com
- Update to version 1.4.0:
  * Add Python3 support.
  * Add support of lmiwbem.
  * Allow plugin test to be run concurrently.
  * Bug fixes:
    + Fix megaraid plugin for dell PERC.
    + Fix local disk rotation speed query on NVMe disk.
    + Fix lsmcli incorrect try-expect on local disk query.
    + Fix all the gcc compile warnings.
    + Fix the obsolete usage of AC_OUTPUT in configure.ac.
  * Library adds:
    + Query serial of local disk:
    lsm_local_disk_serial_num_get()/lsm.LocalDisk.serial_num_get()
    + Query LED status of local disk:
    lsm_local_disk_led_status_get()/lsm.LocalDisk.led_status_get()
    + Query link speed of local disk:
    lsm_local_disk_link_speed_get()/lsm.LocalDisk.link_speed_get()
- Changes for version 1.3.5:
  * Bug fixes:
    + Fix anon_uid/anon_gid handling.
    + Fix HPSA plugin on capabilities, system status, system mode.
    + Fix running lsmcli on python 2.6.
    + Fix missing vpd83 optional property in C library.
  * Enhancements:
    + Rewrite C simulator plugin to support state saving.
* Sun Nov 27 2016 jengelh@inai.de
- Adjust rpm group categories to match what is used in other
  packages.
- Avoid suppressing error outputs in scriptlets. If it happens,
  we want to know about it.
* Tue Aug  9 2016 mpluskal@suse.com
- Update to version 1.3.4:
  * hpsa: Update cacheless variable
* Mon Aug  1 2016 fge@redhat.com
- Update to version 1.3.3:
  * Bug fix release, check this link for detail:
    https://github.com/libstorage/libstoragemgmt/releases/tag/1.3.3
* Tue Jul 19 2016 nwang@suse.com
- bsc#988547, add require of python-libstoragemgmt-clibs.
* Thu May 19 2016 fge@redhat.com
- Update to version 1.3.2 (boo#980653):
  * Fix local disk VPD83 searching in fakeroot(change root) when
    '/dev' is not mounted.
  * New configure option to skip memory leak check test.
  * Fix regression introduced by 1.3.1 when run as non-root user.
  * New configure option '--without-test' to skip all test cases and
    their build requirements.
* Fri May 13 2016 fge@redhat.com
- Upgrade to version 1.3.1 (boo#980041):
  * Fix local disk querying in fakeroot(change root) when '/dev'
    is not mounted.
* Fri May 13 2016 fge@redhat.com
- Upgrade to version 1.3.0:
  * Change the raid card cache split (%%read, %%write)
  * Retrieve/update cache information of both the card and
    physical disks (enable/disable caching etc.)
  * Turn on/off identify and fault LEDs
  * Retrieve information on batteries
  * Retrieve a physical disk RPM, link type and location string for
    a disk
  * Retrieve the vpd 0x83 for directly attached disk(s)
  * Given a vpd 0x83 return list of local disk paths
  * Given a disk path return the vpd 0x83 value
  * Retrieve list of local disks
- Removed package:
  * libstoragemgmt-rest -- droped by upstream.
* Sat Feb  6 2016 mpluskal@suse.com
- Make building more verbose
- Small spec file cleanups
* Wed Jun 24 2015 fge@redhat.com
- Upgrade to version 1.2.3:
  * Bug fixes:
  * lsmcli bash completion: Fix syntax error.
  * lsmcli bash completion: Fix volume-delete.
  * lsmcli bash completion: Add missing completions.
  * Fix: selinux dac_override
  * Manpage: Update hpsa and megaraid plugin manpages.
  * HP Smart Array Plugin: Fix pool querying on P410i.
  * MegaRAID Plugin: Fix bug when no volume configured.
* Thu Jun 18 2015 mpluskal@suse.com
- Cleanup changelog formatting
- Update dependencies
* Wed Jun 17 2015 fge@redhat.com
- Upgrade to version 1.2.1.
- New sub-pacakges:
  * libstoragemgmt-megaraid-plugin
    New plugin in 1.2.0 release.
  * libstoragemgmt-hpsa-plugin
    New plugin in 1.2.0 release.
  * libstoragemgmt-udev
    The udev file has nothing to do with the libraray.
    It just scan the SCSI target when got
    REPORTED_LUNS_DATA_HAS_CHANGED in udev.
- New rpmbuild switch: '--without test'
    Use to skip 'make check' test to save debug time.
- Fix incorrect post scripts for plugin packages.
    User case:
    The libstoragemgmt daemon need to be restarted on new plugin
    install or plugin uninstall, so that the daemon could create
    new or stop existing plugin connection.
    But old macros:
  * The %%service_del_postun only try-restart daemon on upgrade
    which is not required here.
  * The %%service_del_postun only 'daemon-reload' on uninstall
    which is not required here.
  * The %%service_add_post does not restart daemon.
    So we have to use hardcoded systemd commands.
- Add bash-completion script for lsmcli.
- Use systemd-tmpfiles to create socket file in /run folder.
- Add %%ghost ownership for socket file and folder in /run folder.
* Thu May 14 2015 nwang@suse.com
- Add conditions for libyajl and macro tmpfiles_create to
  support build against SLE12.
* Thu Apr  9 2015 mpluskal@suse.com
- Rename python package to match python packaging guidelines
* Wed Apr  8 2015 mpluskal@suse.com
- Disable checks as they seem to fail on OBS
* Wed Apr  8 2015 mpluskal@suse.com
- Use pkgconfig() dependencies
- Enable checks
* Mon Mar 16 2015 mpluskal@suse.com
- More cleanups
* Fri Mar 13 2015 mpluskal@suse.com
- Cleanup package
* Thu Dec 11 2014 nwang@suse.com
- Initial package version 1.1.0 for Fate#314409.
